@@ -1,7 +1,7 @@
 package App::CalendarDatesUtils;
 
 our $DATE = '2019-06-26'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -38,23 +38,23 @@ instead to list dates from all available years.
 _
             schema => 'int*',
             pos => 0,
-            tags => ['category:filtering'],
+            tags => ['category:entry-filtering'],
         },
         month => {
             schema => ['int*', in=>[1, 12]],
             pos => 1,
-            tags => ['category:filtering'],
+            tags => ['category:entry-filtering'],
         },
         day => {
             schema => ['int*', in=>[1, 31]],
             pos => 2,
-            tags => ['category:filtering'],
+            tags => ['category:entry-filtering'],
         },
         all_years => {
             summary => 'List dates from all available years '.
                 'instead of a single year',
             schema => 'true*',
-            tags => ['category:filtering'],
+            tags => ['category:entry-filtering'],
         },
         modules => {
             summary => 'Name(s) of Calendar::Dates::* module (without the prefix)',
@@ -68,8 +68,35 @@ _
         all_modules => {
             summary => 'Use all installed Calendar::Dates::* modules',
             schema => 'true*',
+            cmdline_aliases => {a=>{}},
             tags => ['category:module-selection'],
         },
+        all_entries => {
+            summary => 'Return all entries (include low-priority ones)',
+            schema => 'true*',
+            cmdline_aliases => {A=>{}},
+            description => <<'_',
+
+By default, low-priority entries (entries tagged `low-priority`) are not
+included. This option will include those entries.
+
+_
+            tags => ['category:entry-filtering'],
+        },
+        include_tags => {
+            'x.name.is_plural' => 1,
+            'x.name.singular' => 'include_tag',
+            schema => ['array*', of=>'str*'],
+            cmdline_aliases => {t=>{}},
+            tags => ['category:entry-filtering'],
+        },
+        exclude_tags => {
+            'x.name.is_plural' => 1,
+            'x.name.singular' => 'exclude_tag',
+            schema => ['array*', of=>'str*'],
+            cmdline_aliases => {T=>{}},
+            tags => ['category:entry-filtering'],
+        },
         params => {
             summary => 'Specify parameters',
             'x.name.is_plural' => 1,
@@ -85,7 +112,7 @@ _
             schema => 'bool*',
             'summary' => "Only show entries that are less than (at least) today's date",
             'summary.alt.bool.not' => "Filter entries that are less than (at least) today's date",
-            tags => ['category:filtering'],
+            tags => ['category:entry-filtering'],
         },
     },
     args_rels => {
@@ -118,6 +145,13 @@ sub list_calendar_dates {
         $modules = $args{modules};
     }
 
+    my $params = {};
+    $params->{include_tags} = delete $args{include_tags}
+        if $args{include_tags};
+    $params->{exclude_tags} = delete $args{exclude_tags}
+        if $args{exclude_tags};
+    $params->{all} = delete $args{all_entries};
+
     my @rows;
     for my $mod (@$modules) {
         $mod = "Calendar::Dates::$mod" unless $mod =~ /\ACalendar::Dates::/;
@@ -180,7 +214,7 @@ App::CalendarDatesUtils - Utilities related to Calendar::Dates
 
 =head1 VERSION
 
-This document describes version 0.006 of App::CalendarDatesUtils (from Perl distribution App-CalendarDatesUtils), released on 2019-06-26.
+This document describes version 0.007 of App::CalendarDatesUtils (from Perl distribution App-CalendarDatesUtils), released on 2019-06-26.
 
 =head1 DESCRIPTION
 
@@ -211,6 +245,13 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all_entries> => I<true>
+
+Return all entries (include low-priority ones).
+
+By default, low-priority entries (entries tagged C<low-priority>) are not
+included. This option will include those entries.
+
 =item * B<all_modules> => I<true>
 
 Use all installed Calendar::Dates::* modules.
@@ -225,6 +266,10 @@ List dates from all available years instead of a single year.
 
 Whether to show detailed record for each date.
 
+=item * B<exclude_tags> => I<array[str]>
+
+=item * B<include_tags> => I<array[str]>
+
 =item * B<modules> => I<array[perl::modname]>
 
 Name(s) of Calendar::Dates::* module (without the prefix).
